==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/VMRSCODE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour VMRSCODE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="VMRSCODE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMLEVELID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSASSEMBLYID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCOMPNENTID"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VMRSCODE_Type", propOrder = {
    "systemlevelid",
    "vmrsassemblyid",
    "vmrscompnentid"
})
public class VMRSCODE_Type {

    @XmlElement(name = "SYSTEMLEVELID")
    protected SYSTEMLEVELID_Type systemlevelid;
    @XmlElement(name = "VMRSASSEMBLYID")
    protected VMRSASSEMBLYID vmrsassemblyid;
    @XmlElement(name = "VMRSCOMPNENTID")
    protected VMRSCOMPNENTID vmrscompnentid;

    /**
     * Obtient la valeur de la propriété systemlevelid.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMLEVELID_Type }
     *     
     */
    public SYSTEMLEVELID_Type getSYSTEMLEVELID() {
        return systemlevelid;
    }

    /**
     * Définit la valeur de la propriété systemlevelid.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMLEVELID_Type }
     *     
     */
    public void setSYSTEMLEVELID(SYSTEMLEVELID_Type value) {
        this.systemlevelid = value;
    }

    /**
     * Obtient la valeur de la propriété vmrsassemblyid.
     * 
     * @return
     *     possible object is
     *     {@link VMRSASSEMBLYID }
     *     
     */
    public VMRSASSEMBLYID getVMRSASSEMBLYID() {
        return vmrsassemblyid;
    }

    /**
     * Définit la valeur de la propriété vmrsassemblyid.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSASSEMBLYID }
     *     
     */
    public void setVMRSASSEMBLYID(VMRSASSEMBLYID value) {
        this.vmrsassemblyid = value;
    }

    /**
     * Obtient la valeur de la propriété vmrscompnentid.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCOMPNENTID }
     *     
     */
    public VMRSCOMPNENTID getVMRSCOMPNENTID() {
        return vmrscompnentid;
    }

    /**
     * Définit la valeur de la propriété vmrscompnentid.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCOMPNENTID }
     *     
     */
    public void setVMRSCOMPNENTID(VMRSCOMPNENTID value) {
        this.vmrscompnentid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/VMRSCODE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for VMRSCODE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="VMRSCODE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMLEVELID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSASSEMBLYID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCOMPNENTID"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VMRSCODE_Type", propOrder = {
    "systemlevelid",
    "vmrsassemblyid",
    "vmrscompnentid"
})
public class VMRSCODE_Type {

    @XmlElement(name = "SYSTEMLEVELID")
    protected SYSTEMLEVELID_Type systemlevelid;
    @XmlElement(name = "VMRSASSEMBLYID")
    protected VMRSASSEMBLYID vmrsassemblyid;
    @XmlElement(name = "VMRSCOMPNENTID")
    protected VMRSCOMPNENTID vmrscompnentid;

    /**
     * Gets the value of the systemlevelid property.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMLEVELID_Type }
     *     
     */
    public SYSTEMLEVELID_Type getSYSTEMLEVELID() {
        return systemlevelid;
    }

    /**
     * Sets the value of the systemlevelid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMLEVELID_Type }
     *     
     */
    public void setSYSTEMLEVELID(SYSTEMLEVELID_Type value) {
        this.systemlevelid = value;
    }

    /**
     * Gets the value of the vmrsassemblyid property.
     * 
     * @return
     *     possible object is
     *     {@link VMRSASSEMBLYID }
     *     
     */
    public VMRSASSEMBLYID getVMRSASSEMBLYID() {
        return vmrsassemblyid;
    }

    /**
     * Sets the value of the vmrsassemblyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSASSEMBLYID }
     *     
     */
    public void setVMRSASSEMBLYID(VMRSASSEMBLYID value) {
        this.vmrsassemblyid = value;
    }

    /**
     * Gets the value of the vmrscompnentid property.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCOMPNENTID }
     *     
     */
    public VMRSCOMPNENTID getVMRSCOMPNENTID() {
        return vmrscompnentid;
    }

    /**
     * Sets the value of the vmrscompnentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCOMPNENTID }
     *     
     */
    public void setVMRSCOMPNENTID(VMRSCOMPNENTID value) {
        this.vmrscompnentid = value;
    }

}
